@@ -700,7 +700,7 @@ void            _LikelihoodFunction::PopulateConditionalProbabilities   (long in
                 if (runMode == _hyphyLFConditionProbsWeightedSum || runMode == _hyphyLFConditionProbsMaxProbClass || runMode == _hyphyLFConditionMPIIterate) {
                     //if (branchIndex>=0)
                     //  ((_TheTree*)LocateVar(theTrees.list_data[index]))->AddBranchToForcedRecomputeList (branchIndex+((_TheTree*)LocateVar(theTrees.list_data[index]))->GetLeafCount());
-
+                 hyFloat*        start_of_buffer = buffer + (hmmCatCount?hmmCatSize:1)*blockLength;
 #ifdef          __HYPHYMPI__
                     if (runMode == _hyphyLFConditionMPIIterate) {
                         long offset = resTransferMatrix.GetVDim();
@@ -712,16 +712,29 @@ void            _LikelihoodFunction::PopulateConditionalProbabilities   (long in
                     } else
 
 #endif
-
-                        ComputeBlock    (index, buffer + (hmmCatCount?hmmCatSize:1)*blockLength, useThisPartitonIndex, branchIndex, branchValues);
-
+                    ComputeBlock    (index, start_of_buffer, useThisPartitonIndex, branchIndex, branchValues);
+                    
+                    /***
+                     
+                        SLKP 20230912: TODO why is this always being forced to recompute?
+                        When weights of category variables are being updated (and nothing esle), this offers a great caching opportunity
+                        At least need to document specific cases when the cachine fails.
+                    ***/
+                    
                     if (runMode != _hyphyLFConditionMPIIterate && usedCachedResults) {
                         bool saveFR = forceRecomputation;
                         forceRecomputation = true;
-                        ComputeBlock    (index, buffer + (hmmCatCount?hmmCatSize:1)*blockLength, useThisPartitonIndex, branchIndex, branchValues);
+                        ComputeBlock    (index, start_of_buffer , useThisPartitonIndex, branchIndex, branchValues);
                         forceRecomputation = saveFR;
                     }
-
+                            
+                    /*if (hy_env::EnvVariableTrue("UBER_VERBOSE_DEBUG")) {
+                        printf ("\n\n");
+                        
+                        for (unsigned long i = 0; i < blockLength; i++) {
+                            printf ("%ld\t%ld\t%ld\t%16.12g\n",index,i,useThisPartitonIndex, start_of_buffer[i]);
+                        }
+                    }*/
 
                     if (runMode == _hyphyLFConditionProbsWeightedSum || runMode == _hyphyLFConditionMPIIterate) {
                         long lowerBound  = hmmCatCount?blockLength*currentHMMCat:0,
@@ -871,8 +884,14 @@ _List*   _LikelihoodFunction::RecoverAncestralSequencesMarginal (long index, _Ma
                                                  branchID+iNodeCount, &branchValues);
                 for (long siteID = 0; siteID < patternCount; siteID++) {
                     long scaleDiff = (scalersSpecState.list_data[siteID]-scalersBaseline.list_data[siteID]);
+                    
+
                     hyFloat ratio = siteLikelihoodsSpecState[siteID]/siteLikelihoods[siteID];
                     
+                    /*if (ratio > 1 ) {
+                        printf ("%s/%d : %g, %g\n", ((_CalcNode*)blockTree->flatCLeaves.GetItem(branchID))->GetName()->get_str(),  currentChar, ratio);
+                    }*/
+
                     if (scaleDiff > 0) {
                         ratio *= acquireScalerMultiplier(scaleDiff);
                     }
