@@ -5,7 +5,7 @@
  Copyright (C) 1997-now
  Core Developers:
  Sergei L Kosakovsky Pond (sergeilkp@icloud.com)
- Art FY Poon    (apoon@cfenet.ubc.ca)
+ Art FY Poon    (apoon42@uwo.ca)
  Steven Weaver (sweaver@temple.edu)
  
  Module Developers:
@@ -165,17 +165,17 @@ _SimpleList     updateNodes,
                 flatLeaves,
                 flatTree,
                 theFrequencies;
-_Parameter      *iNodeCache,
+hyFloat      *iNodeCache,
                 *theProbs;
 _SimpleList taggedInternals;
-_GrowingVector* lNodeResolutions;
+_Vector* lNodeResolutions;
 float scalar;
 
 void *node_cache, *nodRes_cache, *nodFlag_cache, *scalings_cache, *prob_cache, *freq_cache, *root_cache, *result_cache, *root_scalings, *model;
 
 void _OCLEvaluator::init(   long esiteCount,
                                     long ealphabetDimension,
-                                    _Parameter* eiNodeCache)
+                                    hyFloat* eiNodeCache)
 {
     clean = false;
     contextSet = false;
@@ -204,7 +204,7 @@ int _OCLEvaluator::setupContext(void)
 
     //long nodeResCount = sizeof(lNodeResolutions->theData)/sizeof(lNodeResolutions->theData[0]);
     long nodeFlagCount = flatLeaves.lLength*siteCount;
-    long nodeResCount = lNodeResolutions->GetUsed();
+    long nodeResCount = lNodeResolutions->get_used();
     int roundCharacters = roundUpToNextPowerOfTwo(alphabetDimension);
 //    long nodeCount = flatLeaves.lLength + flatNodes.lLength + 1;
 //    long iNodeCount = flatNodes.lLength + 1;
@@ -682,27 +682,27 @@ double _OCLEvaluator::oclmain(void)
     printf("Update Nodes:");
     for (int i = 0; i < updateNodes.lLength; i++)
     {
-        printf(" %i ", updateNodes.lData[i]);
+        printf(" %i ", updateNodes.list_data[i]);
     }
     printf("\n");
 
     printf("Tagged Internals:");
     for (int i = 0; i < taggedInternals.lLength; i++)
     {
-        printf(" %i", taggedInternals.lData[i]);
+        printf(" %i", taggedInternals.list_data[i]);
     }
     printf("\n");
 */
     long nodeCode, parentCode;
     bool isLeaf;
-    _Parameter* tMatrix;
+    hyFloat* tMatrix;
     int a1, a2;
     //printf("updateNodes.lLength: %i", updateNodes.lLength);
     //#pragma omp parallel for default(none) shared(updateNodes, flatParents, flatLeaves, flatCLeaves, flatTree, alphabetDimension, model, roundCharacters) private(nodeCode, parentCode, isLeaf, tMatrix, a1, a2)
     for (int nodeID = 0; nodeID < updateNodes.lLength; nodeID++)
     {
-        nodeCode = updateNodes.lData[nodeID];
-        parentCode = flatParents.lData[nodeCode];
+        nodeCode = updateNodes.list_data[nodeID];
+        parentCode = flatParents.list_data[nodeCode];
 
         isLeaf = nodeCode < flatLeaves.lLength;
 
@@ -765,8 +765,8 @@ double _OCLEvaluator::oclmain(void)
     for (int nodeIndex = 0; nodeIndex < updateNodes.lLength; nodeIndex++)
     {
         //printf("NewNode\n");
-        long    nodeCode = updateNodes.lData[nodeIndex],
-                parentCode = flatParents.lData[nodeCode];
+        long    nodeCode = updateNodes.list_data[nodeIndex],
+                parentCode = flatParents.list_data[nodeCode];
 
         //printf("NewNode: %i, NodeCode: %i\n", nodeIndex, nodeCode);
         bool isLeaf = nodeCode < flatLeaves.lLength;
@@ -774,7 +774,7 @@ double _OCLEvaluator::oclmain(void)
         if (isLeaf)
         {
             long nodeCodeTemp = nodeCode;
-            int tempIntTagState = taggedInternals.lData[parentCode];
+            int tempIntTagState = taggedInternals.list_data[parentCode];
             int ambig = 0;
             for (int aI = 0; aI < siteCount; aI++)
                 if (lNodeFlags[nodeCode*siteCount + aI] < 0)
@@ -787,7 +787,7 @@ double _OCLEvaluator::oclmain(void)
                 ciErr1 |= clSetKernelArg(ckLeafKernel, 7, sizeof(cl_long), (void*)&parentCode);
                 ciErr1 |= clSetKernelArg(ckLeafKernel, 9, sizeof(cl_int), (void*)&tempIntTagState);
                 ciErr1 |= clSetKernelArg(ckLeafKernel, 10, sizeof(cl_int), (void*)&nodeIndex);
-                taggedInternals.lData[parentCode] = 1;
+                taggedInternals.list_data[parentCode] = 1;
 
                 //printf("Leaf!\n");
 #ifdef __VERBOSE__
@@ -802,7 +802,7 @@ double _OCLEvaluator::oclmain(void)
                 ciErr1 |= clSetKernelArg(ckAmbigKernel, 7, sizeof(cl_long), (void*)&parentCode);
                 ciErr1 |= clSetKernelArg(ckAmbigKernel, 9, sizeof(cl_int), (void*)&tempIntTagState);
                 ciErr1 |= clSetKernelArg(ckAmbigKernel, 10, sizeof(cl_int), (void*)&nodeIndex);
-                taggedInternals.lData[parentCode] = 1;
+                taggedInternals.list_data[parentCode] = 1;
 
                 //printf("ambig!\n");
 #ifdef __VERBOSE__
@@ -822,12 +822,12 @@ double _OCLEvaluator::oclmain(void)
             long tempLeafState = 0;
             nodeCode -= flatLeaves.lLength;
             long nodeCodeTemp = nodeCode;
-            int tempIntTagState = taggedInternals.lData[parentCode];
+            int tempIntTagState = taggedInternals.list_data[parentCode];
             ciErr1 |= clSetKernelArg(ckInternalKernel, 5, sizeof(cl_long), (void*)&nodeCodeTemp);
             ciErr1 |= clSetKernelArg(ckInternalKernel, 6, sizeof(cl_long), (void*)&parentCode);
             ciErr1 |= clSetKernelArg(ckInternalKernel, 8, sizeof(cl_int), (void*)&tempIntTagState);
             ciErr1 |= clSetKernelArg(ckInternalKernel, 9, sizeof(cl_int), (void*)&nodeIndex);
-            taggedInternals.lData[parentCode] = 1;
+            taggedInternals.list_data[parentCode] = 1;
 #ifdef __VERBOSE__
             printf("Internal Started (ParentCode: %i)...", parentCode);
 #endif
@@ -1046,11 +1046,11 @@ double _OCLEvaluator::launchmdsocl( _SimpleList& eupdateNodes,
                                     _SimpleList& eflatCLeaves,
                                     _SimpleList& eflatLeaves,
                                     _SimpleList& eflatTree,
-                                    _Parameter* etheProbs,
+                                    hyFloat* etheProbs,
                                     _SimpleList& etheFrequencies,
                                     long* elNodeFlags,
                                     _SimpleList& etaggedInternals,
-                                    _GrowingVector* elNodeResolutions)
+                                    _Vector* elNodeResolutions)
 {
 #ifdef __OCLPOSIX__
     clock_gettime(CLOCK_MONOTONIC, &mainStart);
