@@ -301,6 +301,26 @@ HBLObjectRef   FetchObjectFromVariableByTypeIndex (long idx, const unsigned long
     return nil;
 }
 
+//__________________________________________________________________________________
+HBLObjectRef   FetchObjectFromVariableByTypeIndexWithoutCompute (long idx, const unsigned long objectClass, long command_id, _String *errMsg) {
+    _Variable * v = FetchVar (idx);
+    if (v) {
+        if (objectClass == HY_ANY_OBJECT || v->ObjectClass () == objectClass) {
+            return v->GetValue();
+        }
+        if (command_id >= 0 || errMsg) {
+            if (command_id >= 0) {
+                HandleApplicationError (v->GetName()->Enquote() & (" must refer to a ") & FetchObjectNameFromType (objectClass) & " in call to "
+                                         &_HY_ValidHBLExpressions.RetrieveKeyByPayload(command_id) & '.');
+            } else {
+                HandleApplicationError (errMsg->Replace ("_VAR_NAME_ID_", *v->GetName(), true));
+            }
+        }
+    }
+    return nil;
+}
+
+
 //__________________________________________________________________________________
 long LocateVarByName (_String const& name) {
     return variableNames.Find (&name);
