@@ -302,7 +302,11 @@ void    _VariableContainer::ScanModelBasedVariables (_String const & fullName, _
                 _Variable * spawnedVar = CheckReceptacle(&var_name, kEmptyString, false, false);
                 spawnedVar->SetBounds (aVar->GetLowerBound(), aVar->GetUpperBound());
 
-                if (aVar->IsIndependent()) {
+                if (aVar->IsIndependent() && spawnedVar->IsIndependent()) {
+                /***
+                        20230918: SLKP
+                        By adding the check on spawnedVar->IsIndependent(), the code ensures that if a local variable already CONSTRAINED, the container retains memory of this constraint
+                 */
                     PushIndVariable(spawnedVar->get_index(), mVars.get(i));
                 } else {
                     PushDepVariable(spawnedVar->get_index(), mVars.get(i));
@@ -515,6 +519,10 @@ bool _VariableContainer::NeedToExponentiate (bool ignoreCats, _AVLListX* cache)
             return handle_cache (var_index);
         };
 
+        /*if (hy_env::EnvVariableTrue("UBER_VERBOSE_DEBUG")) {
+            printf ("\n####%s\n", GetName()->get_str());
+            printf ("Local-i %d\nGlobal %d\nLocal-d%d\n", AnyLocalVariable (iVariables, has_changed), gVariables && gVariables->Any(has_changed_global), AnyLocalVariable (dVariables, has_changed));
+        }*/
         
         return AnyLocalVariable (iVariables, has_changed) ||
                gVariables && gVariables->Any(has_changed_global) ||
