@@ -1235,72 +1235,6 @@ return log_likel;
 }
 #endif
 
-#ifdef __NEVER_DEFINED__
-//___________________________________________________________________________________________
-void    _DynamicBgm::SetDataMatrix (_Matrix * data)
-{
-    scores_cached   = FALSE;
-
-    if (obsData)    {
-        DeleteObject (obsData);    // dispense with previous data matrix
-    }
-    obsData         = data;
-    obsData->CheckIfSparseEnough(TRUE);
-
-
-    // reset data-dependent member variables
-    for (long node = 0; node < num_nodes; node++) {
-        has_missing.list_data[node] = 0;
-        num_levels.list_data[node] = 0;
-    }
-
-
-    // check for missing data and compute levels
-    if (obsData->GetVDim() == 2*num_nodes) {
-        long    nrows = obsData->GetHDim(),
-                obs,
-                node;
-
-        for (long col = 0; col < obsData->GetVDim(); col++) {
-            node = col / 2;
-
-            if (is_discrete.list_data[node]) {
-                if (col % 2 == 0) {
-                    num_levels.list_data[node] = 1;    // reset for new variable
-                }
-
-                for (long row = 0; row < nrows; row++) {
-                    obs = (*obsData)(row,col);
-
-                    if (has_missing[node] == 0 && obs < 0) {
-                        has_missing.list_data[node] = 1;
-                        continue;   // skip next step to check levels
-                    }
-
-                    obs++;  // adjust for zero-indexing
-                    if (obs > num_levels.list_data[node]) {
-                        num_levels.list_data[node]++;
-                    }
-                }
-            } else {
-                // continuous node defined to have no levels
-                num_levels.list_data[node] = 0;
-            }
-        }
-    } else {
-        _String errorMsg ("Number of variables in data matrix do not match number of nodes in graph.");
-        WarnError (errorMsg);       // note, this produces a crash because the batch file proceeds to execute
-        // BGM routines without data. - AFYP
-    }
-
-
-    last_node_order.Clear();        // forget the last step taken in MCMC chain
-    best_node_order.Clear();
-
-    CacheNodeScores();
-}
-#endif
-
 
 //___________________________________________________________________________________________
 void    _DynamicBgm::CacheNodeScores (void)
